@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.2.1';
 
 1;
 
@@ -40,6 +40,26 @@ dedicated servers with the help of sparrow console client.
 The notion of sparrow plugins is very close to the conception of CPAN modules in Perl or Ruby gems in Ruby.
 It's just a small suites of scripts to solve a specific tasks.
 
+Supported plugin types.
+
+Sparrow supports two types of plugins depending on underlying runner to execute plugin scenarios. They are:
+
+=over
+
+=item *
+
+L<Outthentic|https://github.com/melezhik/outthentic> Plugins
+
+
+
+=item *
+
+L<SWAT|https://github.com/melezhik/swat> Plugins
+
+
+
+=back
+
 To find a specific sparrow plugin say this:
 
     $ sparrow plg search nginx
@@ -106,18 +126,28 @@ plugin configuration
 
 =back
 
-Plugin configuration is just a text file in one of 2 formats:
+Plugin configuration is just a text file in one of 4 formats:
 
 =over
 
 =item *
 
-L<Config::General|https://metacpan.org/pod/Config::General> format
+L<Config::General|https://metacpan.org/pod/Config::General> format - consumed by Outthentic plugins
 
 
 =item *
 
-YAML format
+YAML format - consumed by Outthentic plugins
+
+
+=item *
+
+JSON format - consumed by Outthentic plugins
+
+
+=item *
+
+L<Config::Tiny|https://metacpan.org/pod/Config::Tiny> format - consumed by Swat plugins
 
 
 =back
@@ -136,9 +166,6 @@ Sparrow tasks boxes are JSON format files to describe sequential tasks to run.
 
 You could think about sparrow boxes as of multi tasks. Sparrow runs tasks from the box sequentially.
 
-B<I<WARNING!>> This feature is still experimental, do not rely on it on production code, as
-things might change.
-
 
 =head1 API
 
@@ -179,7 +206,7 @@ For example:
 
     $ sparrow project remove web-servers
 
-NOTE! This command will remove all project tasks as well!
+B<I<NOTE!>> This command will remove all project tasks as well!
 
 
 =head2 Plugins API
@@ -296,6 +323,17 @@ For example:
     $ sparrow plg remove df-check
 
 
+=head3 Getting plugin man page
+
+If plugin author supply his plugin with man page it could be shown as:
+
+B<sparrow plg man $plugin_name>
+
+For example:
+
+    $ sparrow plg man df-check
+
+
 =head2 Tasks API
 
 
@@ -409,6 +447,8 @@ B<verbose>
 
 =head3 Setting runtime parameters 
 
+B<I<NOTE!>> Runtime parameters are only supported for Outthentic plugins.
+
 It is possible to pass I<whatever> runtime configuration parameters when running tasks or plugins:
 
     $ sparrow plg run df-check --param threshold=60
@@ -443,7 +483,7 @@ SWAT Plugins
 =back
 
 Both runners accept specific parameters. For outthentic runner parameters follow L<Outthentic|https://github.com/melezhik/outthentic#options>
-documentation. For swat runner parameters follow L<swat|https://github.com/melezhik/swat#swat-runner> documentation.
+documentation. For swat runner parameters follow L<Swat|https://github.com/melezhik/swat#swat-runner> documentation.
 
 Here are some examples:
 
@@ -806,7 +846,7 @@ Once your get you token, setup a sparrowhub credentials on the machine where you
         "token" : "ADB4F4DC-9F3B-11E5-B394-D4E152C9AB83"
     }
 
-NOTE! Another way to provide SparrowHub credentials is to set C<$sph_user> and C<$sph_token> environment variables:
+B<I<NOTE!>> Another way to provide SparrowHub credentials is to set C<$sph_user> and C<$sph_token> environment variables:
 
     $ export sph_user=melezhik 
     $ export sph_token=ADB4F4DC-9F3B-11E5-B394-D4E152C9AB83
